Name
That doesn't look like a valid network name.
Too long network name.
Network {$ nw.name $}
You must supply a network.
IP Version 4 6 CIDR
Please input a valid cidr range.
Enable DHCP {$ 'Show More Properties' | translate $} IPv6 Address Mode IPv6 RA Mode Gateway
Please input a valid address.
Subnet Pool
That doesn't look like a valid subnet pool id.
Prefix length DNS Nameservers Allocation Pools
Start
That doesn't look like a valid ip address.
End
That doesn't look like a valid ip address.
Host Routes
Destination
That doesn't look like a valid ip address.
Nexthop
That doesn't look like a valid ip address.
Tenant ID
That doesn't look like a valid tenant id.